# Quickstart

## Installation
pydiverse.transform is distributed on [PyPi](https://pypi.org/project/pydiverse-transform/).
To use it, just install it with pip:

```shell
pip install pydiverse-transform
```
